==> foundation-2.6.1.tgz: package/Paperclip/Paperclip.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Paperclip = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M30.267 88.384c-2.726 0-6.235-.922-9.739-4.426-4.621-4.621-5.203-9.081-4.878-12.013.381-3.436 2.14-6.747 5.225-9.833L50.287 32.7c8.215-8.212 13.68-5.208 16.206-2.684 3.056 3.057 5.06 8.338-2.747 16.143L36.668 73.237l-5.271-5.271 27.078-27.078c4.172-4.174 3.211-5.135 2.745-5.601-.369-.369-1.49-1.485-5.662 2.684L26.146 67.383c-1.279 1.281-2.852 3.252-3.087 5.387-.213 1.922.682 3.859 2.743 5.916 2.555 2.558 4.487 2.286 5.125 2.194 1.74-.243 3.725-1.442 5.739-3.456 2.495-2.489 32.596-32.591 34.901-34.901 2.849-2.849 4.66-5.62 5.383-8.236 1.048-3.786-.206-7.387-3.83-11.013-3.825-3.825-9.986-7.829-19.308 1.495L21.601 56.982a3.726 3.726 0 01-5.271 0 3.725 3.725 0 010-5.271l32.213-32.212c9.957-9.96 20.836-10.508 29.849-1.495 6.989 6.989 6.981 13.789 5.747 18.269-1.087 3.931-3.473 7.697-7.297 11.522-2.308 2.31-32.414 32.416-34.904 34.902-3.208 3.213-6.564 5.086-9.967 5.567a11.74 11.74 0 01-1.704.12z"
  }));
});
Paperclip.displayName = 'Paperclip';
export const PaperclipDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Paperclip/Paperclip.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Paperclip = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M30.267 88.384c-2.726 0-6.235-.922-9.739-4.426-4.621-4.621-5.203-9.081-4.878-12.013.381-3.436 2.14-6.747 5.225-9.833L50.287 32.7c8.215-8.212 13.68-5.208 16.206-2.684 3.056 3.057 5.06 8.338-2.747 16.143L36.668 73.237l-5.271-5.271 27.078-27.078c4.172-4.174 3.211-5.135 2.745-5.601-.369-.369-1.49-1.485-5.662 2.684L26.146 67.383c-1.279 1.281-2.852 3.252-3.087 5.387-.213 1.922.682 3.859 2.743 5.916 2.555 2.558 4.487 2.286 5.125 2.194 1.74-.243 3.725-1.442 5.739-3.456 2.495-2.489 32.596-32.591 34.901-34.901 2.849-2.849 4.66-5.62 5.383-8.236 1.048-3.786-.206-7.387-3.83-11.013-3.825-3.825-9.986-7.829-19.308 1.495L21.601 56.982a3.726 3.726 0 01-5.271 0 3.725 3.725 0 010-5.271l32.213-32.212c9.957-9.96 20.836-10.508 29.849-1.495 6.989 6.989 6.981 13.789 5.747 18.269-1.087 3.931-3.473 7.697-7.297 11.522-2.308 2.31-32.414 32.416-34.904 34.902-3.208 3.213-6.564 5.086-9.967 5.567a11.74 11.74 0 01-1.704.12z"
  }));
});
Paperclip.displayName = 'Paperclip';
export var PaperclipDimensions = {
  height: 100,
  width: 100
};
